--------------------------------------------------------------------------
-- Function: tb_lab1.vhd - Test bench for cnt1s and signextend.
-- Requires: cnts1s and signextend in lab2.vhd
-- Author:   Dr. Jerry H. Tucker
--------------------------------------------------------------------------
LIBRARY IEEE;
USE work.all;
USE IEEE.Std_Logic_1164.all; 
use ieee.numeric_std.all;

ENTITY tb is END tb ;

ARCHITECTURE Test OF tb IS
-- Using constants make the test bench more general
   CONSTANT cM: integer := 4; -- Use 4 bits for short word
   CONSTANT cN: integer := 8; -- Use 8 bits for long word
   Constant MAX: integer := 2**(cM-1)-1; -- Max short word = 7
   Constant MIN: integer := -2**(cM-1);  -- Min short word = -8

   SIGNAL Yout: signed(cN-1 downto 0);
   SIGNAL Xin : signed(cM-1 downto 0) := (others => '0');
   SIGNAL iXin: integer range MIN to MAX;
   SIGNAL iYout: integer range -2**(cN-1) to 2**(cN-1)-1;
   SIGNAL Ones: unsigned(cM - 1 downto 0);
   Signal iOnes: integer;
BEGIN
    U1: ENTITY cnt1s(behav) GENERIC MAP(cM)
                            PORT MAP(unsigned(Xin), Ones);
    U2: ENTITY signextend(behav) GENERIC MAP(M => cM, N => cN) 
        PORT MAP(X => Xin, Y => Yout);
--  The following is an example of a conditional signal assignment.
--  See DG p 132. It is a shorthand way to avoid having to
--  create a process containing an if statement.
    iXin <= iXin + 1 after 10 ns when iXin < MAX else MIN after 10 ns;
    
--  The next two statements show how to convert between integer 
--  and signed/unsigned. The functions are part of the numeric package.
--  See DG p 249
    Xin <= to_signed(iXin, cM);
    iYout <= to_integer(Yout);
    iOnes <= to_integer(Ones);
END Test;









